
%This mfile was created in Matlab R2010b.  Results were published in the
%following paper (Mackey and Lamb, 2013).  Please cite the following paper should these codes be
%used for a publication.

%Mackey, B.H., and Lamb, M.P., 2013, 
%Deciphering boulder mobility and erosion from cosmogenic nuclide exposure dating: 
%Journal of Geophysical Research: Earth Surface,doi: 10.1002/jgrf.20035

%Disclaimer:  These codes have only been tested for the conditions published
%in the manuscript. Numerical errors are likely outside of these bounds given
%the crude iteration schemes used.  Use at your own risk.

%Copyright (C) 2012 Michael Lamb <mpl@gps.caltech.edu>

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation. You should have received a copy of the GNU 
% General Public License along with this program.  If not, see 
% http://www.gnu.org/licenses.


%makes a plot of surface concentration of nuclides around the circumference
%of a boulder for a range of diameters

radius = [0.1,0.25,0.5,1,1.5,2,3,4,5].*1000 ; %converts selected radii from m to mm

s = 1

for s = 1:length(radius)


rho = radius(s); %circle radius (mm)

%First set up the boulder framwork with a polar matrix
spokes = 200;
nodes = 1;

r = linspace(0,rho,nodes); %the spoke separated into evenly seperated nodes
theta = linspace(0,2*pi,spokes)'; %Angular interval of spokes
Xcol = []; %big column of all x values
Ycol = []; %big column lf all y values
m = 1; %increment

for m = 1:nodes;
    [X,Y]=pol2cart(theta,r(m)); %Cartesian coordinates of each concentric ring
    
    Xcol = [Xcol;X];
    Ycol = [Ycol;Y];
end

Lx = length(Xcol)
y_alt(1:Lx)=0; %makes it a 2-D disc

[accum] = sphere_line3_Lal(Xcol./1000, y_alt./1000, Ycol./1000, rho./1000); %this function assumes meters
accum = accum.*0.5252; %conversion for normalization by flat surface and all rays


surfaceprof = accum
surfacedist = linspace(0,2*pi,spokes)./pi;

eval(['surfaceprof' num2str(rho) '=surfaceprof'])


clear accum surfaceprof 
% 
end
figure
pl1 = plot(surfacedist,surfaceprof100, 'k-')
hold on
pl2 = plot(surfacedist,surfaceprof250)
pl3 = plot(surfacedist,surfaceprof500, 'k--')
pl4 = plot(surfacedist,surfaceprof1000)
pl5 = plot(surfacedist,surfaceprof1500, 'k.-')
pl6 = plot(surfacedist,surfaceprof2000)
pl7 = plot(surfacedist,surfaceprof3000, 'k:')
pl8 = plot(surfacedist,surfaceprof4000)
pl9 = plot(surfacedist,surfaceprof5000, 'r-')
xlabel('Angular distance (pi)')
ylabel('Normalized nuclide concentration')
xlim([0 2])
lg1 = legend([pl1 pl2 pl3 pl4 pl5 pl6 pl7 pl8 pl9],'100 mm', '250 mm', '500 mm', '1000 mm', '1500 mm', '2000 mm', '3000 mm', '4000 mm', '5000 mm')
set(lg1, 'location', 'southwest')
