%This mfile was created in Matlab R2010b.  Results were published in the
%following paper (Mackey and Lamb, 2013).  Please cite the following paper should these codes be
%used for a publication.

%Mackey, B.H., and Lamb, M.P., 2013, 
%Deciphering boulder mobility and erosion from cosmogenic nuclide exposure dating: 
%Journal of Geophysical Research: Earth Surface,doi: 10.1002/jgrf.20035

%Disclaimer:  These codes have only been tested for the conditions published
%in the manuscript. Numerical errors are likely outside of these bounds given
%the crude iteration schemes used.  Use at your own risk.

%Copyright (C) 2013 Michael Lamb <mpl@gps.caltech.edu>

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation. You should have received a copy of the GNU 
% General Public License along with this program.  If not, see 
% http://www.gnu.org/licenses.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure1 = figure
set(figure1, 'Position', [200   200   450  800])

load('mcLal_noeros_varrolls_n200_rad2000.mat')


subplot(3,1,1)
set(gca,'FontSize',12, 'FontName', 'MyriadPro-Regular')
%plot of mean boulder concentration

xt =linspace(40000/length(mc5.avgvarmean),40000,length(mc5.avgvarmean));

pl1a = plot(xt,mc5.avgmean, 'k-');

hold on

xlabel('Time (years)')
ylabel('C (atoms/node)')


%plot non-eroding boulder with a range of movment events

subplot(3,1,2)
set(gca,'FontSize',12, 'FontName', 'MyriadPro-Regular')
%no movement events
xt =linspace(40000/length(mc1.avgvarmean),40000,length(mc1.avgvarmean));

pl21a = plot(xt,mc1.avgvarmean, 'k-');

hold on

xdot = linspace(40000/1,40000, 1);

pl21b = plot(xdot,mc1.avgvarmean(end), 'ko');


%3 movement events
xt =linspace(40000/length(mc3.avgvarmean),40000,length(mc3.avgvarmean));

pl2c = plot(xt,mc3.avgvarmean, 'r-');

xdot = linspace(40000/3,40000, 3);
int = length(mc3.avgvarmean)./3;

pl21d = plot(xdot,mc3.avgvarmean(int:int:end), 'ro');


%5 movement events

xt =linspace(40000/length(mc5.avgvarmean),40000,length(mc5.avgvarmean));

pl2d = plot(xt,mc5.avgvarmean, 'b-');

xdot = linspace(40000/5,40000, 5);
int = length(mc5.avgvarmean)./5;

pl21e = plot(xdot,mc5.avgvarmean(int:int:end), 'bo');


%10 movement events
xt =linspace(40000/length(mc10.avgvarmean),40000,length(mc10.avgvarmean));

pl2f = plot(xt,mc10.avgvarmean, 'g-');

xdot = linspace(40000/10,40000, 10);
int = length(mc10.avgvarmean)./10;

pl2g = plot(xdot,mc10.avgvarmean(int:int:end), 'go');


%15 movement evetns
xt =linspace(40000/length(mc15.avgvarmean),40000,length(mc15.avgvarmean));

pl2h = plot(xt,mc15.avgvarmean, 'k-');

xdot = linspace(40000/15,40000, 15);
int = length(mc15.avgvarmean)./15;

pl2i = plot(xdot,mc15.avgvarmean(int:int:end), 'ko');

ylabel('C_N')
xlabel('Time (years)')


load('mcLal_eros_varrolls_n200_rad2000.mat')

%plot eroding line on first plot
subplot(3,1,1)


xt =linspace(40000/length(mc5.avgvarmean),40000,length(mc5.avgvarmean));

pl1 = plot(xt,mc5.avgmean, 'b-');




%plot boulder eroding at 0.05 mm/yr for range of mobilizing scenarios
subplot(3,1,3)
set(gca,'FontSize',12, 'FontName', 'MyriadPro-Regular')

xt =linspace(40000/length(mc1.avgvarmean),40000,length(mc1.avgvarmean));

pl3a = plot(xt,mc1.avgvarmean, 'k-');

hold on

xdot = linspace(40000/1,40000, 1);

pl3b = plot(xdot,mc1.avgvarmean(end), 'ko');



%3 movement events
xt =linspace(40000/length(mc3.avgvarmean),40000,length(mc3.avgvarmean));

pl3c = plot(xt,mc3.avgvarmean, 'r-');

xdot = linspace(40000/3,40000, 3);
int = length(mc3.avgvarmean)./3;

pl3d = plot(xdot,mc3.avgvarmean(int:int:end), 'ro');


%5 movement events

xt =linspace(40000/length(mc5.avgvarmean),40000,length(mc5.avgvarmean));

pl3e = plot(xt,mc5.avgvarmean, 'b-');

xdot = linspace(40000/5,40000, 5);
int = length(mc5.avgvarmean)./5;

pl3f = plot(xdot,mc5.avgvarmean(int:int:end), 'bo');


%10 movement events
xt =linspace(40000/length(mc10.avgvarmean),40000,length(mc10.avgvarmean));

pl3g = plot(xt,mc10.avgvarmean, 'g-');

xdot = linspace(40000/10,40000, 10);
int = length(mc10.avgvarmean)./10;

pl3h = plot(xdot,mc10.avgvarmean(int:int:end), 'go');


%15 movement evetns
xt =linspace(40000/length(mc15.avgvarmean),40000,length(mc15.avgvarmean));

pl3i = plot(xt,mc15.avgvarmean, 'k-');

xdot = linspace(40000/15,40000, 15);
int = length(mc15.avgvarmean)./15;

pl3j = plot(xdot,mc15.avgvarmean(int:int:end), 'ko');

ylabel('C_N')
xlabel('Time (years)')

