%This mfile was created in Matlab R2010b.  Results were published in the
%following paper (Mackey and Lamb, 2013).  Please cite the following paper should these codes be
%used for a publication.

%Mackey, B.H., and Lamb, M.P., 2013, 
%Deciphering boulder mobility and erosion from cosmogenic nuclide exposure dating: 
%Journal of Geophysical Research: Earth Surface,doi: 10.1002/jgrf.20035

%Disclaimer:  These codes have only been tested for the conditions published
%in the manuscript. Numerical errors are likely outside of these bounds given
%the crude iteration schemes used.  Use at your own risk.

%Copyright (C) 2013 Michael Lamb <mpl@gps.caltech.edu>

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation. You should have received a copy of the GNU 
% General Public License along with this program.  If not, see 
% http://www.gnu.org/licenses.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This does all the runs for the norm var figure (9B in Mackey and Lamb
%2013)

%Fig 9B - fixed final boulder radius (rstar = 2, or radius = 1.660 m)
%Vary the length of erosion (tstar) by controling initial radius and
%erosion time.
%constant Er of 0.05 mm/yr
tic

Er = 0.05

tstar = 5 %[0.25 0.5 1 1.5 2 3 4] %thickness removed from boulder

eros_mm = tstar.*830 %thickness removed in mm

rad = eros_mm + (2000*0.83) %initial boulder size in mm

ttime = eros_mm./Er %time for each boulder to erode at 0.05 mm/yr


iterations = 100
sizes = length(rad);

q = 1;

for q = 1:sizes;

   rad(q);
    
        
radius = rad(q)
    
load nuclide_sphere_Lal %xn1 yn1 zn1

rolls = 1; %start with 

for rolls = 1:10 %start loop iterating through increasing number of roll events. 
    %rolls '1' will map to mc1, an so on

    rolls
    
%metadata of each run    
mc.iterations = iterations; %number of iterations for each roll number - (monte carlo simulation)
mc.Er = Er; %specified erosion rate
mc.radius = radius; %specified initial radius
mc.concnd = []; %normalised concentration at end of each step (C* = meanconc*Er / Prod rate * efolding length)
mc.timend = []; %normalised time at end of each step (Time*Er/efolding length)

%matrices to collect info:
mc.varmean = []; %outer skin variance/mean
mc.mean = []; %mean skin conc
mc.var = []; %skin conc stdev

for h = 1:iterations, %start loop of iterations - monte carlo simulation 

[stats_all,stats]= boulder_erode_lalMC(radius,rolls,Er,ttime(q)); %calls program to run boulder modelling. output'stats' defined there

%populates mc with data from [stats] - adds column for each iteration
mc.varmean = [mc.varmean,stats(:,5)];
mc.mean = [mc.mean,stats(:,3)];
mc.var = [mc.var,stats(:,4)];
mc.concnd = [mc.concnd,stats(:,7)];
mc.timend = [mc.timend,stats(:,8)];  
h;

end

%calculates averages for all the MC runs
avgvarmean = mean(mc.varmean,2);
avgvar = mean(mc.var,2);
avgmean = mean(mc.mean,2);
stdev = std(mc.varmean,0,2);

%add stats to mc structure data files
mc.avgvarmean = avgvarmean;
mc.avgvar = avgvar;
mc.stdev = stdev;
mc.avgmean = avgmean;

%finally rename mc file 'mcx', where 'x' is the number of rolls
eval(['mc' num2str(rolls) '=mc'])

fprintf('mc batch complete')

end

avgvarmeanF = [mc1.avgvarmean(end), mc2.avgvarmean(end), mc3.avgvarmean(end), mc4.avgvarmean(end), mc5.avgvarmean(end), mc6.avgvarmean(end), mc7.avgvarmean(end), mc8.avgvarmean(end), mc9.avgvarmean(end), mc10.avgvarmean(end)]'
stdvarmeanF =  [mc1.stdev(end), mc2.stdev(end), mc3.stdev(end), mc4.stdev(end), mc5.stdev(end), mc6.stdev(end), mc7.stdev(end), mc8.stdev(end), mc9.stdev(end), mc10.stdev(end)]'
xax = linspace(0,9,10);

tstar_iteration = tstar(q)

filename = [ 'mcLalrstar2_n200_tstar' num2str(tstar_iteration) '.mat' ];
save(filename);


clear mc1 mc2 mc3 mc4 mc5 mc6 mc7 mc8 mc9 mc10 avgvarmeanF stdvarmeanF avgvar

end

toc