%This mfile was created in Matlab R2010b.  Results were published in the
%following paper (Mackey and Lamb, 2013).  Please cite the following paper should these codes be
%used for a publication.

%Mackey, B.H., and Lamb, M.P., 2013, 
%Deciphering boulder mobility and erosion from cosmogenic nuclide exposure dating: 
%Journal of Geophysical Research: Earth Surface,doi: 10.1002/jgrf.20035

%Disclaimer:  These codes have only been tested for the conditions published
%in the manuscript. Numerical errors are likely outside of these bounds given
%the crude iteration schemes used.  Use at your own risk.

%Copyright (C) 2013 Michael Lamb <mpl@gps.caltech.edu>

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation. You should have received a copy of the GNU 
% General Public License along with this program.  If not, see 
% http://www.gnu.org/licenses.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Ft] = sphere_line3_Lal(x_imp, y_imp, z_imp, R_imp)
%x_imp, y_imp, z_imp are vectors of the disc nodes
%R_imp is the total radius of the sphere
%The answer is Ft is the total exposure at each point normalized by the
%vertical ray flux.  ie. this assumes everything is vertical and full
%intensity
%Need to multliply by 0.5252 to normalize by a
%horizontal surface that includes all rays.

load nuclide_sphere_Lal %xn1 yn1 zn1

R = R_imp; %Radius of boulder

%These are the vectors of nodes on the disc you will import
xl = x_imp;
yl = y_imp;
zl = z_imp;
lam = 0.83;

    clear xn yn zn ai bi ci ui xi yi zi d th_d F Ft
for i = 1:length(xl)
    %define nuclide sphere. 
    %This moves the sphere around so it is always cenetered on the node of
    %interest
    xn = xn1+xl(i);
    yn = yn1+yl(i);
    zn = zn1+zl(i);
    
    %define ray paths as lines between nuclide sphere and point of interest
    %and find intersection of a sphere with origin 0, 0, 0 and radius R
    %from http://paulbourke.net/geometry/sphereline/
    
    ai = (xn-xl(i)).^2 +(yn-yl(i)).^2 + (zn-zl(i)).^2;
    bi = 2*((xn-xl(i)).*xl(i) + (yn-yl(i)).*yl(i) + (zn-zl(i)).*zl(i));
    ci = xl(i).^2 + yl(i).^2 + zl(i).^2 - R.^2;
    ui = (-bi + (bi.^2 - 4.*ai.*ci).^0.5) ./(2.*ai); 

    xi = xl(i) + ui.*(xn-xl(i));  %These are the intersection points in the sphere
    yi = yl(i) + ui.*(yn-yl(i));
    zi = zl(i) + ui.*(zn-zl(i));
    %Now find the distance between the intersection points and my point
    d(i,:) = (((xi-xl(i)).^2 + (yi-yl(i)).^2 + (zi-zl(i)).^2).^0.5);
    %d(i,:)=abs(d(i,:));
    %Now find the angle of the ray path
    th_d(i,:) = acos(abs((zn-zl(i)))./(R_nuclide));
    %Calculate the nuclide exposure for each ray path
    F(i,:) = (cos(th_d(i,:))).^2.3.*sin(th_d(i,:)).*exp(-d(i,:)./lam); 
    %Sum over all ray paths
     Ft(i) = sum(F(i,:)).*dA; %Ft is the output - ie the nuclide concentration for each node in the disc. THis us used by the other functions which move and erode the disc
end

end


